@@ -71,7 +71,7 @@ void QueryMeeSettings::openDictionary()
 {
     QString fileName = QFileDialog::getOpenFileName(0,
                                                     tr("Open dictionary"),
-                                                    QDir::homePath());
+                                                    QDir::homePath(),"*.kvtml");
     openDictionaryFile(fileName);
 }
 
